# Quantinuum schemas

Shared data models for Quantinuum.

## Dependencies

We try to keep the dependencies minimal.
However we do need `pydantic` for validation and `pytket` for core (serialisable) models.
